==> backup2swift-0.8.2.tar.gz: backup2swift-0.8.2/backup2swift/tests/test_config.py <==
# -*- coding: utf-8 -*-
"""
    Copyright (C) 2013, 2014 Kouhei Maeda <mkouhei@palmtb.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
import unittest
from backup2swift import config as c


class ConfigTests(unittest.TestCase):

    def test_check_config(self):
        self.assertEqual(('https://example.org/auth/v1.0',
                          'username',
                          'password',
                          '10',
                          True,
                          None),
                         c.check_config('examples/bu2sw.conf'))

    def test_check_config_ignore(self):
        self.assertEqual(('https://example.org/auth/v1.0',
                          'username',
                          'password',
                          '10',
                          False,
                          None),
                         c.check_config('examples/bu2sw_ignore_verify.conf'))

==> backup2swift-0.8.3.tar.gz: backup2swift-0.8.3/backup2swift/tests/test_config.py <==
# -*- coding: utf-8 -*-
"""
    Copyright (C) 2013, 2014 Kouhei Maeda <mkouhei@palmtb.net>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
import unittest
from backup2swift import config as c


class ConfigTests(unittest.TestCase):
    """ test module config. """

    def test_check_config(self):
        """ unit test for check_config """
        self.assertEqual(('https://example.org/auth/v1.0',
                          'username',
                          'password',
                          '10',
                          True,
                          None),
                         c.check_config('examples/bu2sw.conf'))

    def test_check_config_ignore(self):
        """ unit test for check_config ignore case """
        self.assertEqual(('https://example.org/auth/v1.0',
                          'username',
                          'password',
                          '10',
                          False,
                          None),
                         c.check_config('examples/bu2sw_ignore_verify.conf'))
